@@ -18,7 +18,7 @@
  *
  * THIS IS A PRIVATE HEADER FOR USE ONLY IN Gtk2 ITSELF.
  *
- * $Id: gtk2perl-private.h 2054 2008-10-05 12:49:36Z tsch $
+ * $Id$
  */
 
 #ifndef _GTK2PERL_PRIVATE_H_
@@ -43,25 +43,4 @@ gboolean gtk2perl_tree_view_row_separator_func (GtkTreeModel *model,
 				                gpointer      data);
 #endif
 
-/* Implemented in PangoAttributes.xs. */
-void gtk2perl_pango_attribute_register_custom_type (PangoAttrType type, const char *package);
-
-#define GTK2PERL_PANGO_ATTR_REGISTER_CUSTOM_TYPE(attr, package)	\
-{								\
-	static gboolean type_registered_already = FALSE;	\
-	if (!type_registered_already) {				\
-		gtk2perl_pango_attribute_register_custom_type	\
-			((attr)->klass->type, package);		\
-		type_registered_already = TRUE;			\
-	}							\
-}
-
-#define GTK2PERL_PANGO_ATTR_STORE_INDICES(offset, attr)	\
-	if (items == offset + 2) {			\
-		guint start = SvUV (ST (offset));	\
-		guint end = SvUV (ST (offset + 1));	\
-		attr->start_index = start;		\
-		attr->end_index = end;			\
-	}
-
 #endif /* _GTK2PERL_PRIVATE_H_ */
